==> adminer-3.2.0.zip: adminer-3.2.0/adminer/lang/ru.inc.php <==
<?php
$translations = array(
	'Login' => 'Войти',
	'Logout successful.' => 'Вы успешно покинули систему.',
	'Invalid credentials.' => 'Неправильное имя пользователя или пароль.',
	'Server' => 'Сервер',
	'Username' => 'Имя пользователя',
	'Password' => 'Пароль',
	'Select database' => 'Выбрать базу данных',
	'Invalid database.' => 'Плохая база данных.',
	'Create new database' => 'Создать новую базу данных',
	'Table has been dropped.' => 'Таблица была удалена.',
	'Table has been altered.' => 'Таблица была изменена.',
	'Table has been created.' => 'Таблица была создана.',
	'Alter table' => 'Изменить таблицу',
	'Create table' => 'Создать таблицу',
	'Table name' => 'Название таблицы',
	'engine' => 'тип',
	'collation' => 'режим сопоставления',
	'Column name' => 'Название поля',
	'Type' => 'Тип',
	'Length' => 'Длина',
	'Auto Increment' => 'Автоматическое приращение',
	'Options' => 'Действие',
	'Save' => 'Сохранить',
	'Drop' => 'Удалить',
	'Database has been dropped.' => 'База данных была удалена.',
	'Database has been created.' => 'База данных была создана.',
	'Database has been renamed.' => 'База данных была переименована.',
	'Database has been altered.' => 'База данных была изменена.',
	'Alter database' => 'Изменить базу данных',
	'Create database' => 'Создать базу данных',
	'SQL command' => 'SQL запрос',
	'Dump' => 'Дамп',
	'Logout' => 'Выйти',
	'database' => 'база данных',
	'Use' => 'Выбрать',
	'No tables.' => 'В базе данных нет таблиц.',
	'select' => 'выбрать',
	'Create new table' => 'Создать новую таблицу',
	'Item has been deleted.' => 'Запись удалена.',
	'Item has been updated.' => 'Запись обновлена.',
	'Item%s has been inserted.' => 'Запись%s была вставлена.',
	'Edit' => 'Редактировать',
	'Insert' => 'Вставить',
	'Save and insert next' => 'Сохранить и вставить еще',
	'Delete' => 'Стереть',
	'Database' => 'База данных',
	'Routines' => 'Хранимые процедуры и функции',
	'Indexes have been altered.' => 'Индексы изменены.',
	'Indexes' => 'Индексы',
	'Alter indexes' => 'Изменить индексы',
	'Add next' => 'Добавить еще',
	'Language' => 'Язык',
	'Select' => 'Выбрать',
	'New item' => 'Новая запись',
	'Search' => 'Поиск',
	'Sort' => 'Сортировать',
	'descending' => 'по убыванию',
	'Limit' => 'Лимит',
	'No rows.' => 'Нет записей.',
	'Action' => 'Действие',
	'edit' => 'редактировать',
	'Page' => 'Страница',
	'Query executed OK, %d row(s) affected.' => array('Запрос завершен, изменена %d запись.', 'Запрос завершен, изменены %d записи.', 'Запрос завершен, изменено %d записей.'),
	'Error in query' => 'Ошибка в запросe',
	'Execute' => 'Выполнить',
	'Table' => 'Таблица',
	'Foreign keys' => 'Внешние ключи',
	'Triggers' => 'Триггеры',
	'View' => 'Представление',
	'Unable to select the table' => 'Не удалось получить данные из таблицы',
	'Invalid CSRF token. Send the form again.' => 'Недействительный CSRF токен. Отправите форму ещё раз.',
	'Comment' => 'Комментарий',
	'Default values' => 'Значения по умолчанию',
	'%d byte(s)' => array('%d байт', '%d байта', '%d байтов'),
	'No commands to execute.' => 'Нет команд для выполнения.',
	'Unable to upload a file.' => 'Не удалось загрузить файл на сервер.',
	'File upload' => 'Загрузить файл на сервер',
	'File uploads are disabled.' => 'Загрузка файлов на сервер запрещена.',
	'Routine has been called, %d row(s) affected.' => array('Была вызвана процедура, %d запись была изменена.', 'Была вызвана процедура, %d записи было изменено.', 'Была вызвана процедура, %d записей было изменено.'),
	'Call' => 'Вызвать',
	'No extension' => 'Нет расширений',
	'None of the supported PHP extensions (%s) are available.' => 'Не доступно ни одного расширения из поддерживаемых (%s).',
	'Session support must be enabled.' => 'Сессии должны быть включены.',
	'Session expired, please login again.' => 'Срок действия сесси истек, нужно снова войти в систему.',
	'Text length' => 'Длина текста',
	'Foreign key has been dropped.' => 'Внешний ключ был удален.',
	'Foreign key has been altered.' => 'Внешний ключ был изменен.',
	'Foreign key has been created.' => 'Внешний ключ был создан.',
	'Foreign key' => 'Внешний ключ',
	'Target table' => 'Результирующая таблица',
	'Change' => 'Изменить',
	'Source' => 'Источник',
	'Target' => 'Цель',
	'Add column' => 'Добавить колонку',
	'Alter' => 'Изменить',
	'Add foreign key' => 'Добавить внешний ключ',
	'ON DELETE' => 'При стирании',
	'ON UPDATE' => 'При обновлении',
	'Index Type' => 'Тип индекса',
	'Column (length)' => 'Колонка (длина)',
	'View has been dropped.' => 'Представление было удалено.',
	'View has been altered.' => 'Представление было изменено.',
	'View has been created.' => 'Представление было создано.',
	'Alter view' => 'Изменить представление',
	'Create view' => 'Создать представление',
	'Name' => 'Название',
	'Process list' => 'Список процессов',
	'%d process(es) have been killed.' => array('Был завершен %d процесс.', 'Было завершено %d процесса.', 'Было завершёно %d процессов.'),
	'Kill' => 'Завершить',
	'Parameter name' => 'Название параметра',
	'Database schema' => 'Схема базы данных',
	'Create procedure' => 'Создать процедуру',
	'Create function' => 'Создать функцию',
	'Routine has been dropped.' => 'Процедура была удалена.',
	'Routine has been altered.' => 'Процедура была изменена.',
	'Routine has been created.' => 'Процедура была создана.',
	'Alter function' => 'Изменить функцию',
	'Alter procedure' => 'Изменить процедуру',
	'Return type' => 'Возвращаемый тип',
	'Add trigger' => 'Добавить триггер',
	'Trigger has been dropped.' => 'Триггер был удален.',
	'Trigger has been altered.' => 'Триггер был изменен.',
	'Trigger has been created.' => 'Триггер был создан.',
	'Alter trigger' => 'Изменить триггер',
	'Create trigger' => 'Создать триггер',
	'Time' => 'Время',
	'Event' => 'Событие',
	'%s version: %s through PHP extension %s' => 'Версия %s: %s с PHP-расширением %s',
	'%d row(s)' => array('%d строка', '%d строки', '%d строк'),
	'Remove' => 'Удалить',
	'Are you sure?' => 'Вы уверены?',
	'Privileges' => 'Полномочия',
	'Create user' => 'Создать пользователя',
	'User has been dropped.' => 'Пользователь был удален.',
	'User has been altered.' => 'Пользователь был изменен.',
	'User has been created.' => 'Пользователь был создан.',
	'Hashed' => 'Хешировано',
	'Column' => 'Колонка',
	'Routine' => 'Процедура',
	'Grant' => 'Позволить',
	'Revoke' => 'Запретить',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Слишком большой объем POST-данных. Пошлите меньший объем данных или увеличьте параметр конфигурационной директивы %s.',
	'Logged as: %s' => 'Вы вошли как: %s',
	'Move up' => 'Переместить вверх',
	'Move down' => 'Переместить вниз',
	'Functions' => 'Функции',
	'Aggregation' => 'Агрегация',
	'Export' => 'Экспорт',
	'Output' => 'Выходные данные',
	'open' => 'открыть',
	'save' => 'сохранить',
	'Format' => 'Формат',
	'Tables' => 'Таблицы',
	'Data' => 'Данные',
	'Event has been dropped.' => 'Событие было удалено.',
	'Event has been altered.' => 'Событие было изменено.',
	'Event has been created.' => 'Событие было создано.',
	'Alter event' => 'Изменить событие',
	'Create event' => 'Создать событие',
	'At given time' => 'В данное время',
	'Every' => 'Каждые',
	'Events' => 'События',
	'Schedule' => 'Расписание',
	'Start' => 'Начало',
	'End' => 'Конец',
	'Status' => 'Состояние',
	'On completion preserve' => 'После завершения сохранить',
	'Tables and views' => 'Таблицы и представления',
	'Data Length' => 'Объём данных',
	'Index Length' => 'Объём индексов',
	'Data Free' => 'Свободное место',
	'Collation' => 'Режим сопоставления',
	'Analyze' => 'Анализировать',
	'Optimize' => 'Оптимизировать',
	'Check' => 'Проверить',
	'Repair' => 'Исправить',
	'Truncate' => 'Очистить',
	'Tables have been truncated.' => 'Таблицы были очищены.',
	'Rows' => 'Строк',
	',' => ' ',
	'Tables have been moved.' => 'Таблицы были перемещены.',
	'Move to other database' => 'Переместить в другою базу данных',
	'Move' => 'Переместить',
	'Engine' => 'Тип',
	'Save and continue edit' => 'Сохранить и продолжить редактирование',
	'original' => 'исходный',
	'%d item(s) have been affected.' => array('Была изменена %d запись.', 'Были изменены %d записи.', 'Было изменено %d записей.'),
	'whole result' => 'весь результат',
	'Tables have been dropped.' => 'Таблицы были удалены.',
	'Clone' => 'Клонировать',
	'Partition by' => 'Разделить по',
	'Partitions' => 'Разделы',
	'Partition name' => 'Название раздела',
	'Values' => 'Параметры',
	'%d row(s) have been imported.' => array('Импортирована %d строка.', 'Импортировано %d строки.', 'Импортировано %d строк.'),
	'Import' => 'Импорт',
	'Stop on error' => 'Остановить при ошибке',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Достигнуто максимальное значение количества доступных полей. Увеличьте %s и %s.',
	'anywhere' => 'в любом месте',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5.$3.$1',
	'[yyyy]-mm-dd' => 'дд.мм.[гггг]',
	'History' => 'История',
	'Variables' => 'Переменные',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Колонки должны иметь одинаковые типы данных, в результирующей колонке должен быть индекс, данные для импорта должны существовать.',
	'Relations' => 'Реляции',
	'Run file' => 'Запустить файл',
	'Clear' => 'Очистить',
	'Maximum allowed file size is %sB.' => 'Максимальный разрешенный размер файла - %sB.',
	'Numbers' => 'Число',
	'Date and time' => 'Дата и время',
	'Strings' => 'Строки',
	'Binary' => 'Двоичный тип',
	'Lists' => 'Списки',
	'Editor' => 'Редактор',
	'E-mail' => 'Электропочта',
	'From' => 'От',
	'Subject' => 'Кому',
	'Send' => 'Послать',
	'%d e-mail(s) have been sent.' => array('Было отправлено %d письмо.', 'Было отправлено %d письма.', 'Было отправлено %d писем.'),
	'Webserver file %s' => 'Файл %s на вебсервере',
	'File does not exist.' => 'Такого файла не существует.',
	'%d in total' => 'Всего %d',
	'Permanent login' => 'Оставаться в системе',
	'Databases have been dropped.' => 'Базы данных удалены.',
	'Search data in tables' => 'Поиск в таблицах',
	'schema' => 'схема',
	'Schema' => 'Схема',
	'Alter schema' => 'Изменить схему',
	'Create schema' => 'Новая схема',
	'Schema has been dropped.' => 'Схема удалена.',
	'Schema has been created.' => 'Создана новая схема.',
	'Schema has been altered.' => 'Схема изменена.',
	'Sequences' => '«Последовательности»',
	'Create sequence' => 'Создать «последовательность»',
	'Alter sequence' => 'Изменить «последовательность»',
	'Sequence has been dropped.' => '«Последовательность» удалена.',
	'Sequence has been created.' => 'Создана новая «последовательность».',
	'Sequence has been altered.' => '«Последовательность» изменена.',
	'User types' => 'Типы пользователей',
	'Create type' => 'Создать тип',
	'Alter type' => 'Изменить тип',
	'Type has been dropped.' => 'Тип удален.',
	'Type has been created.' => 'Создан новый тип.',
	'Double click on a value to modify it.' => 'Кликни два раза по значению, чтобы его изменить.',
	'Use edit link to modify this value.' => 'Изменить это значение можно с помощью ссылки «изменить».',
	'last' => 'последняя',
	'From server' => 'С сервера',
	'System' => 'Движок',
	'Select data' => 'Выбрать',
	'Show structure' => 'Показать структуру',
	'empty' => 'пусто',
	'Network' => 'Сеть',
	'Geometry' => 'Геометрия',
	'File exists.' => 'Файл уже существует.',
	'Attachments' => 'Прикрепленные файлы',
	'%d query(s) executed OK.' => array('%d запрос выполнен успешно.', '%d запроса выполнено успешно.', '%d запросов выполнено успешно.'),
	'Show only errors' => 'Только ошибки',
	'Last page' => 'Последняя страница',
	'Refresh' => 'Обновить',
	'Invalid schema.' => 'Неправильная схема.',
	'Please use one of the extensions %s.' => 'Используйте одно из этих расширений %s.',
	'now' => 'сейчас',
	'ltr' => 'ltr',
);

==> adminer-3.6.1.zip: adminer-3.6.1/adminer/lang/ru.inc.php <==
<?php
$translations = array(
	'Login' => 'Войти',
	'Logout successful.' => 'Вы успешно покинули систему.',
	'Invalid credentials.' => 'Неправильное имя пользователя или пароль.',
	'Server' => 'Сервер',
	'Username' => 'Имя пользователя',
	'Password' => 'Пароль',
	'Select database' => 'Выбрать базу данных',
	'Invalid database.' => 'Плохая база данных.',
	'Create new database' => 'Создать новую базу данных',
	'Table has been dropped.' => 'Таблица была удалена.',
	'Table has been altered.' => 'Таблица была изменена.',
	'Table has been created.' => 'Таблица была создана.',
	'Alter table' => 'Изменить таблицу',
	'Create table' => 'Создать таблицу',
	'Table name' => 'Название таблицы',
	'engine' => 'тип',
	'collation' => 'режим сопоставления',
	'Column name' => 'Название поля',
	'Type' => 'Тип',
	'Length' => 'Длина',
	'Auto Increment' => 'Автоматическое приращение',
	'Options' => 'Действие',
	'Save' => 'Сохранить',
	'Drop' => 'Удалить',
	'Database has been dropped.' => 'База данных была удалена.',
	'Database has been created.' => 'База данных была создана.',
	'Database has been renamed.' => 'База данных была переименована.',
	'Database has been altered.' => 'База данных была изменена.',
	'Alter database' => 'Изменить базу данных',
	'Create database' => 'Создать базу данных',
	'SQL command' => 'SQL запрос',
	'Dump' => 'Дамп',
	'Logout' => 'Выйти',
	'database' => 'база данных',
	'Use' => 'Выбрать',
	'No tables.' => 'В базе данных нет таблиц.',
	'select' => 'выбрать',
	'Create new table' => 'Создать новую таблицу',
	'Item has been deleted.' => 'Запись удалена.',
	'Item has been updated.' => 'Запись обновлена.',
	'Item%s has been inserted.' => 'Запись%s была вставлена.',
	'Edit' => 'Редактировать',
	'Insert' => 'Вставить',
	'Save and insert next' => 'Сохранить и вставить еще',
	'Delete' => 'Стереть',
	'Database' => 'База данных',
	'Routines' => 'Хранимые процедуры и функции',
	'Indexes have been altered.' => 'Индексы изменены.',
	'Indexes' => 'Индексы',
	'Alter indexes' => 'Изменить индексы',
	'Add next' => 'Добавить еще',
	'Language' => 'Язык',
	'Select' => 'Выбрать',
	'New item' => 'Новая запись',
	'Search' => 'Поиск',
	'Sort' => 'Сортировать',
	'descending' => 'по убыванию',
	'Limit' => 'Лимит',
	'No rows.' => 'Нет записей.',
	'Action' => 'Действие',
	'edit' => 'редактировать',
	'Page' => 'Страница',
	'Query executed OK, %d row(s) affected.' => array('Запрос завершен, изменена %d запись.', 'Запрос завершен, изменены %d записи.', 'Запрос завершен, изменено %d записей.'),
	'Error in query' => 'Ошибка в запросe',
	'Execute' => 'Выполнить',
	'Table' => 'Таблица',
	'Foreign keys' => 'Внешние ключи',
	'Triggers' => 'Триггеры',
	'View' => 'Представление',
	'Unable to select the table' => 'Не удалось получить данные из таблицы',
	'Invalid CSRF token. Send the form again.' => 'Недействительный CSRF токен. Отправите форму ещё раз.',
	'Comment' => 'Комментарий',
	'Default values' => 'Значения по умолчанию',
	'%d byte(s)' => array('%d байт', '%d байта', '%d байтов'),
	'No commands to execute.' => 'Нет команд для выполнения.',
	'Unable to upload a file.' => 'Не удалось загрузить файл на сервер.',
	'File upload' => 'Загрузить файл на сервер',
	'File uploads are disabled.' => 'Загрузка файлов на сервер запрещена.',
	'Routine has been called, %d row(s) affected.' => array('Была вызвана процедура, %d запись была изменена.', 'Была вызвана процедура, %d записи было изменено.', 'Была вызвана процедура, %d записей было изменено.'),
	'Call' => 'Вызвать',
	'No extension' => 'Нет расширений',
	'None of the supported PHP extensions (%s) are available.' => 'Не доступно ни одного расширения из поддерживаемых (%s).',
	'Session support must be enabled.' => 'Сессии должны быть включены.',
	'Session expired, please login again.' => 'Срок действия сесси истек, нужно снова войти в систему.',
	'Text length' => 'Длина текста',
	'Foreign key has been dropped.' => 'Внешний ключ был удален.',
	'Foreign key has been altered.' => 'Внешний ключ был изменен.',
	'Foreign key has been created.' => 'Внешний ключ был создан.',
	'Foreign key' => 'Внешний ключ',
	'Target table' => 'Результирующая таблица',
	'Change' => 'Изменить',
	'Source' => 'Источник',
	'Target' => 'Цель',
	'Add column' => 'Добавить колонку',
	'Alter' => 'Изменить',
	'Add foreign key' => 'Добавить внешний ключ',
	'ON DELETE' => 'При стирании',
	'ON UPDATE' => 'При обновлении',
	'Index Type' => 'Тип индекса',
	'Column (length)' => 'Колонка (длина)',
	'View has been dropped.' => 'Представление было удалено.',
	'View has been altered.' => 'Представление было изменено.',
	'View has been created.' => 'Представление было создано.',
	'Alter view' => 'Изменить представление',
	'Create view' => 'Создать представление',
	'Name' => 'Название',
	'Process list' => 'Список процессов',
	'%d process(es) have been killed.' => array('Был завершен %d процесс.', 'Было завершено %d процесса.', 'Было завершёно %d процессов.'),
	'Kill' => 'Завершить',
	'Parameter name' => 'Название параметра',
	'Database schema' => 'Схема базы данных',
	'Create procedure' => 'Создать процедуру',
	'Create function' => 'Создать функцию',
	'Routine has been dropped.' => 'Процедура была удалена.',
	'Routine has been altered.' => 'Процедура была изменена.',
	'Routine has been created.' => 'Процедура была создана.',
	'Alter function' => 'Изменить функцию',
	'Alter procedure' => 'Изменить процедуру',
	'Return type' => 'Возвращаемый тип',
	'Add trigger' => 'Добавить триггер',
	'Trigger has been dropped.' => 'Триггер был удален.',
	'Trigger has been altered.' => 'Триггер был изменен.',
	'Trigger has been created.' => 'Триггер был создан.',
	'Alter trigger' => 'Изменить триггер',
	'Create trigger' => 'Создать триггер',
	'Time' => 'Время',
	'Event' => 'Событие',
	'%s version: %s through PHP extension %s' => 'Версия %s: %s с PHP-расширением %s',
	'%d row(s)' => array('%d строка', '%d строки', '%d строк'),
	'Remove' => 'Удалить',
	'Are you sure?' => 'Вы уверены?',
	'Privileges' => 'Полномочия',
	'Create user' => 'Создать пользователя',
	'User has been dropped.' => 'Пользователь был удален.',
	'User has been altered.' => 'Пользователь был изменен.',
	'User has been created.' => 'Пользователь был создан.',
	'Hashed' => 'Хешировано',
	'Column' => 'Колонка',
	'Routine' => 'Процедура',
	'Grant' => 'Позволить',
	'Revoke' => 'Запретить',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Слишком большой объем POST-данных. Пошлите меньший объем данных или увеличьте параметр конфигурационной директивы %s.',
	'Logged as: %s' => 'Вы вошли как: %s',
	'Move up' => 'Переместить вверх',
	'Move down' => 'Переместить вниз',
	'Functions' => 'Функции',
	'Aggregation' => 'Агрегация',
	'Export' => 'Экспорт',
	'Output' => 'Выходные данные',
	'open' => 'открыть',
	'save' => 'сохранить',
	'Format' => 'Формат',
	'Tables' => 'Таблицы',
	'Data' => 'Данные',
	'Event has been dropped.' => 'Событие было удалено.',
	'Event has been altered.' => 'Событие было изменено.',
	'Event has been created.' => 'Событие было создано.',
	'Alter event' => 'Изменить событие',
	'Create event' => 'Создать событие',
	'At given time' => 'В данное время',
	'Every' => 'Каждые',
	'Events' => 'События',
	'Schedule' => 'Расписание',
	'Start' => 'Начало',
	'End' => 'Конец',
	'Status' => 'Состояние',
	'On completion preserve' => 'После завершения сохранить',
	'Tables and views' => 'Таблицы и представления',
	'Data Length' => 'Объём данных',
	'Index Length' => 'Объём индексов',
	'Data Free' => 'Свободное место',
	'Collation' => 'Режим сопоставления',
	'Analyze' => 'Анализировать',
	'Optimize' => 'Оптимизировать',
	'Check' => 'Проверить',
	'Repair' => 'Исправить',
	'Truncate' => 'Очистить',
	'Tables have been truncated.' => 'Таблицы были очищены.',
	'Rows' => 'Строк',
	',' => ' ',
	'Tables have been moved.' => 'Таблицы были перемещены.',
	'Move to other database' => 'Переместить в другою базу данных',
	'Move' => 'Переместить',
	'Engine' => 'Тип',
	'Save and continue edit' => 'Сохранить и продолжить редактирование',
	'original' => 'исходный',
	'%d item(s) have been affected.' => array('Была изменена %d запись.', 'Были изменены %d записи.', 'Было изменено %d записей.'),
	'whole result' => 'весь результат',
	'Tables have been dropped.' => 'Таблицы были удалены.',
	'Clone' => 'Клонировать',
	'Partition by' => 'Разделить по',
	'Partitions' => 'Разделы',
	'Partition name' => 'Название раздела',
	'Values' => 'Параметры',
	'%d row(s) have been imported.' => array('Импортирована %d строка.', 'Импортировано %d строки.', 'Импортировано %d строк.'),
	'Import' => 'Импорт',
	'Stop on error' => 'Остановить при ошибке',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Достигнуто максимальное значение количества доступных полей. Увеличьте %s и %s.',
	'anywhere' => 'в любом месте',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5.$3.$1',
	'[yyyy]-mm-dd' => 'дд.мм.[гггг]',
	'History' => 'История',
	'Variables' => 'Переменные',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Колонки должны иметь одинаковые типы данных, в результирующей колонке должен быть индекс, данные для импорта должны существовать.',
	'Relations' => 'Реляции',
	'Run file' => 'Запустить файл',
	'Clear' => 'Очистить',
	'Maximum allowed file size is %sB.' => 'Максимальный разрешенный размер файла - %sB.',
	'Numbers' => 'Число',
	'Date and time' => 'Дата и время',
	'Strings' => 'Строки',
	'Binary' => 'Двоичный тип',
	'Lists' => 'Списки',
	'Editor' => 'Редактор',
	'E-mail' => 'Электропочта',
	'From' => 'От',
	'Subject' => 'Кому',
	'Send' => 'Послать',
	'%d e-mail(s) have been sent.' => array('Было отправлено %d письмо.', 'Было отправлено %d письма.', 'Было отправлено %d писем.'),
	'Webserver file %s' => 'Файл %s на вебсервере',
	'File does not exist.' => 'Такого файла не существует.',
	'%d in total' => 'Всего %d',
	'Permanent login' => 'Оставаться в системе',
	'Databases have been dropped.' => 'Базы данных удалены.',
	'Search data in tables' => 'Поиск в таблицах',
	'schema' => 'схема',
	'Schema' => 'Схема',
	'Alter schema' => 'Изменить схему',
	'Create schema' => 'Новая схема',
	'Schema has been dropped.' => 'Схема удалена.',
	'Schema has been created.' => 'Создана новая схема.',
	'Schema has been altered.' => 'Схема изменена.',
	'Sequences' => '«Последовательности»',
	'Create sequence' => 'Создать «последовательность»',
	'Alter sequence' => 'Изменить «последовательность»',
	'Sequence has been dropped.' => '«Последовательность» удалена.',
	'Sequence has been created.' => 'Создана новая «последовательность».',
	'Sequence has been altered.' => '«Последовательность» изменена.',
	'User types' => 'Типы пользователей',
	'Create type' => 'Создать тип',
	'Alter type' => 'Изменить тип',
	'Type has been dropped.' => 'Тип удален.',
	'Type has been created.' => 'Создан новый тип.',
	'Double click on a value to modify it.' => 'Кликни два раза по значению, чтобы его изменить.',
	'Use edit link to modify this value.' => 'Изменить это значение можно с помощью ссылки «изменить».',
	'last' => 'последняя',
	'From server' => 'С сервера',
	'System' => 'Движок',
	'Select data' => 'Выбрать',
	'Show structure' => 'Показать структуру',
	'empty' => 'пусто',
	'Network' => 'Сеть',
	'Geometry' => 'Геометрия',
	'File exists.' => 'Файл уже существует.',
	'Attachments' => 'Прикрепленные файлы',
	'%d query(s) executed OK.' => array('%d запрос выполнен успешно.', '%d запроса выполнено успешно.', '%d запросов выполнено успешно.'),
	'Show only errors' => 'Только ошибки',
	'Last page' => 'Последняя страница',
	'Refresh' => 'Обновить',
	'Invalid schema.' => 'Неправильная схема.',
	'Please use one of the extensions %s.' => 'Используйте одно из этих расширений %s.',
	'now' => 'сейчас',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Таблицы скопированы.',
	'Copy' => 'Копировать',
	'Permanent link' => 'Постоянная ссылка',
	'Edit all' => 'Редактировать всё',
	'HH:MM:SS' => 'ЧЧ:ММ:СС',
);
